package cn.iocoder.yudao.module.product.service.productbrandempower;

import cn.hutool.core.collection.CollectionUtil;
import cn.iocoder.yudao.framework.common.util.spring.enums.CommonStatusEnum;
import cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.util.date.DateUtils;
import cn.iocoder.yudao.framework.mybatis.core.dataobject.BaseDO;
import cn.iocoder.yudao.framework.mybatis.core.service.AbstractService;
import cn.iocoder.yudao.framework.mybatis.core.util.MyBatisUtils;
import cn.iocoder.yudao.framework.security.core.LoginUser;
import cn.iocoder.yudao.framework.security.core.util.SecurityFrameworkUtils;
import cn.iocoder.yudao.module.customer.dal.dataobject.customer.CustomerDO;
import cn.iocoder.yudao.module.customer.dal.mysql.customer.CustomerMapper;
import cn.iocoder.yudao.module.customer.service.customerOperateLog.CustomerOperateLogService;
import cn.iocoder.yudao.module.customer.vo.customerOperateLog.CustomerOperateLogCreateReqVO;
import cn.iocoder.yudao.module.ecw.enums.CustomerOperateTypeEnum;
import cn.iocoder.yudao.module.product.convert.productbrandempower.ProductBrandEmpowerConvert;
import cn.iocoder.yudao.module.product.dal.dataobject.productBrandUnauthEmpower.ProductBrandUnauthEmpowerDO;
import cn.iocoder.yudao.module.product.dal.dataobject.productbrandempower.ProductBrandEmpowerDO;
import cn.iocoder.yudao.module.product.dal.dataobject.productbrank.ProductBrankDO;
import cn.iocoder.yudao.module.product.dal.mysql.productbrandempower.ProductBrandEmpowerMapper;
import cn.iocoder.yudao.module.product.dal.mysql.productbrank.ProductBrankMapper;
import cn.iocoder.yudao.module.product.enums.ErrorCodeConstants;
import cn.iocoder.yudao.module.product.service.productBrandUnauthEmpower.ProductBrandUnauthEmpowerService;
import cn.iocoder.yudao.module.product.vo.productBrandUnauthEmpower.ProductBrandUnauthEmpowerQueryVO;
import cn.iocoder.yudao.module.product.vo.productbrandempower.*;
import cn.iocoder.yudao.module.product.vo.productbrank.ProductBrankRespVO;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.apache.commons.lang3.StringUtils;
import org.jetbrains.annotations.Nullable;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;

import javax.annotation.Resource;
import java.util.Collection;
import java.util.Date;
import java.util.List;
import java.util.Objects;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.product.enums.ErrorCodeConstants.ORDER_NOT_EXISTS;

/**
 * 商品品牌授权 Service 实现类
 *
 * @author 江楠
 */
@Service
@Validated
public class ProductBrandEmpowerServiceImpl extends AbstractService<ProductBrandEmpowerMapper, ProductBrandEmpowerDO> implements ProductBrandEmpowerService {

    @Resource
    private ProductBrandEmpowerMapper productBrandEmpowerMapper;

    @Resource
    private CustomerOperateLogService customerOperateLogService;

    @Resource
    private CustomerMapper customerMapper;

    @Resource
    private ProductBrankMapper productBrankMapper;


    @Override
    public Long createProductBrandEmpower(ProductBrandEmpowerCreateReqVO createReqVO) {
        // 插入
        Long userId = SecurityFrameworkUtils.getLoginUserId();

        ProductBrandEmpowerDO productBrandEmpower = ProductBrandEmpowerConvert.INSTANCE.convert(createReqVO);
        productBrandEmpower.setCreateUserId(userId);
        productBrandEmpower.setCreateTime(new Date());
        productBrandEmpower.setCreateUsername(SecurityFrameworkUtils.getLoginUser().getUsername());

        productBrandEmpowerMapper.insert(productBrandEmpower);

        logCustomerOperate(productBrandEmpower, CustomerOperateTypeEnum.PRODUCT_BRAND_EMPOWER_ADD);

        // 返回
        return productBrandEmpower.getId();
    }

    @Override
    public void updateProductBrandEmpower(ProductBrandEmpowerUpdateReqVO updateReqVO) {
        // 校验存在
        this.validateProductBrandEmpowerExists(updateReqVO.getId());

        // 更新
        ProductBrandEmpowerDO updateObj = ProductBrandEmpowerConvert.INSTANCE.convert(updateReqVO);
        Long userId = SecurityFrameworkUtils.getLoginUserId();

        updateObj.setUpdater(String.valueOf(userId));
        updateObj.setUpdateTime(new Date());
        productBrandEmpowerMapper.updateById(updateObj);
    }

    @Override
    public void deleteProductBrandEmpower(Long id) {

        // 校验存在
        this.validateProductBrandEmpowerExists(id);


        ProductBrandEmpowerDO productBrandEmpower= productBrandEmpowerMapper.selectById(id);

        logCustomerOperate(productBrandEmpower, CustomerOperateTypeEnum.PRODUCT_BRAND_EMPOWER_DELETE);

        Long userId = SecurityFrameworkUtils.getLoginUserId();
        this.update(new LambdaUpdateWrapper<ProductBrandEmpowerDO>()
                .set(BaseDO::getUpdateTime, new Date())
                .set(BaseDO::getUpdater, String.valueOf(userId))
                .set(BaseDO::getDeleted, true)
                .eq(ProductBrandEmpowerDO::getId, id));
    }

    private void logCustomerOperate(ProductBrandEmpowerDO productBrandEmpower, CustomerOperateTypeEnum customerOperateTypeEnum) {
        Long customerId = productBrandEmpower.getCustomerId();
        if (customerId != null) {

            String productBrandName = "";
            ProductBrankDO productBrankDO = productBrankMapper.selectById(productBrandEmpower.getProductBrandId());
            if (productBrankDO != null) {
                productBrandName = productBrankDO.getTitleZh();
            }

            String operateDesc = customerOperateTypeEnum.equals(CustomerOperateTypeEnum.PRODUCT_BRAND_EMPOWER_ADD) ? "添加" : "删除";
            String deletePrefix = customerOperateTypeEnum.equals(CustomerOperateTypeEnum.PRODUCT_BRAND_EMPOWER_DELETE) ? "原" : "";
            //添加了#品牌名称#的授权，授权开始时间：#开始时间#~结束时间#结束时间#，授权模式：无牌价
            //删除了#品牌名称#的授权，原授权开始时间：#开始时间#~结束时间#结束时间#，授权模式：无牌价
            String remark = String.format("%s了[%s]的授权，%s授权时间：%s，授权模式：%s",
                    operateDesc, productBrandName, deletePrefix,
                    productBrandEmpower.getFeeScale() == 0 ? "长期" :
                    (DateUtils.formatDateTime(productBrandEmpower.getStartTime()) + "~" + DateUtils.formatDateTime(productBrandEmpower.getEndTime())),
                    productBrandEmpower.getFeeScale() == 0 ? "无牌价" : "有牌价");

            CustomerDO customerDO = customerMapper.selectById(customerId);
            LoginUser loginUser = SecurityFrameworkUtils.getLoginUser();
            CustomerOperateLogCreateReqVO customerOperateLogCreateReqVO = new CustomerOperateLogCreateReqVO()
                    .setOperator(loginUser == null ?  null : loginUser.getId())
                    .setOperatorName(loginUser == null ?  null : loginUser.getNickname())
                    .setCustomerId(customerDO.getId())
                    .setNumber(customerDO.getNumber())
                    .setName(customerDO.getName())
                    .setOperateType(customerOperateTypeEnum.getValue())
                    .setRemark(remark);
            customerOperateLogService.createOperateLog(customerOperateLogCreateReqVO);
        }
    }

    private void validateProductBrandEmpowerExists(Long id) {
        if (productBrandEmpowerMapper.selectById(id) == null) {
            throw ServiceExceptionUtil.exception(ErrorCodeConstants.PRODUCT_BRAND_EMPOWER_NOT_EXISTS);
        }
    }

    @Override
    public ProductBrandEmpowerDO getProductBrandEmpower(Long id) {
        return productBrandEmpowerMapper.selectById(id);
    }

    @Resource
    ProductBrandUnauthEmpowerService productBrandUnauthEmpowerService;

    @Override
    public GetFeeTypeProductBrandEmpowerRespVO getFeeTypeProductBrandEmpower(GetFeeTypeProductBrandEmpowerReqVO reqVO) {
        if (reqVO.getBrandId() == null || reqVO.getBrandId() == 0) {
            //未备案按无牌价计算
            GetFeeTypeProductBrandEmpowerRespVO respVO = new GetFeeTypeProductBrandEmpowerRespVO();
            respVO.setFeeType("0");
            respVO.setRecordMode("0");
            return respVO;
        }
        ProductBrankDO productBrankDO = productBrankMapper.selectById(reqVO.getBrandId());
        if (productBrankDO == null) {
            //未备案按无牌价计算
            GetFeeTypeProductBrandEmpowerRespVO respVO = new GetFeeTypeProductBrandEmpowerRespVO();
            respVO.setFeeType("0");
            respVO.setRecordMode("0");
            return respVO;
        }

        //查询品牌的备案模式，以及当前商品是否符合品牌商品分类
        ProductBrankRespVO brandRespVo = productBrankMapper.getBrandByProductBrand(reqVO);
        if (brandRespVo == null) {
            //商品不在品牌的适用范围内，算为无备案
            GetFeeTypeProductBrandEmpowerRespVO respVO = new GetFeeTypeProductBrandEmpowerRespVO();
            respVO.setFeeType("0");
            respVO.setRecordMode("0");
            return respVO;
        }
        GetFeeTypeProductBrandEmpowerRespVO respVO = new GetFeeTypeProductBrandEmpowerRespVO();
        //备案状态
        respVO.setRecordMode(brandRespVo.getFiling());
        if (reqVO.getCustomerId() != null && reqVO.getCustomerId() != 0) {
            //查看品牌与客户授权关系
            ProductBrandEmpowerBaseVO productBrandEmpowerBaseVO = new ProductBrandEmpowerBaseVO();
            productBrandEmpowerBaseVO.setProductBrandId(reqVO.getBrandId());
            productBrandEmpowerBaseVO.setCustomerId(reqVO.getCustomerId());
            productBrandEmpowerBaseVO.setStatus(CommonStatusEnum.ENABLE.getStatus());
            //查询的授权信息
            List<ProductBrandEmpowerDO> list = getProductBrandEmpowerList(productBrandEmpowerBaseVO);
            //没有授权的客户
            if (list == null || list.size() == 0) {
                //未授权要查看品牌的授权模式，以及当前客户是否有特殊设置
                if (productBrankDO.getUnauthChargingModel().equals("1")) {
                    ProductBrandUnauthEmpowerQueryVO productBrandUnauthEmpowerQueryVO = new ProductBrandUnauthEmpowerQueryVO();
                    productBrandUnauthEmpowerQueryVO.setProductBrandId(reqVO.getBrandId());
                    productBrandUnauthEmpowerQueryVO.setCustomerId(reqVO.getCustomerId());
                    List<ProductBrandUnauthEmpowerDO> unauthEmpowerList = productBrandUnauthEmpowerService.getProductBrandUnauthEmpowerList(productBrandUnauthEmpowerQueryVO);
                    if (unauthEmpowerList != null && unauthEmpowerList.size() > 0) {
                        //有未授权客户设置
                        respVO.setFeeType(String.valueOf(unauthEmpowerList.get(0).getFeeScale()));
                    } else {
                        //未设置以品牌设置为准
                        respVO.setFeeType(brandRespVo.getUnauthDefaultFeeType());
                    }
                } else {
                    //品牌的未授权为统一模式，所有用户以品牌设置为准
                    respVO.setFeeType(brandRespVo.getUnauthDefaultFeeType());
                }
                return respVO;
            }
            //有授权绑定关系
            ProductBrandEmpowerDO empowerDO = list.get(0);
            //使用系统中的授权关系
            respVO.setFeeType(String.valueOf(empowerDO.getFeeScale()));
        } else {
            respVO.setFeeType(brandRespVo.getFiling());

        }
        return respVO;
    }

    @Override
    public GetFeeTypeProductBrandEmpowerRespVO getFeeTypeByOrder(GetFeeTypeProductBrandByOrderEmpowerReqVO reqVO) {
        if (reqVO.getBrandId() == null || reqVO.getBrandId() == 0) {
            //未备案按无牌价计算
            GetFeeTypeProductBrandEmpowerRespVO respVO = new GetFeeTypeProductBrandEmpowerRespVO();
            respVO.setFeeType("0");
            respVO.setRecordMode("0");
            return respVO;
        }
        ProductBrankDO productBrankDO = productBrankMapper.selectById(reqVO.getBrandId());
        if (productBrankDO == null) {
            //未备案按无牌价计算
            GetFeeTypeProductBrandEmpowerRespVO respVO = new GetFeeTypeProductBrandEmpowerRespVO();
            respVO.setFeeType("0");
            respVO.setRecordMode("0");
            return respVO;
        }

        //查询品牌的备案模式，以及当前商品是否符合品牌商品分类
        ProductBrankRespVO brandRespVo = productBrankMapper.getBrandByProductBrandByParam(reqVO.getProductId(), reqVO.getBrandId());
        if (brandRespVo == null) {
            //商品不在品牌的适用范围内，算为无备案
            GetFeeTypeProductBrandEmpowerRespVO respVO = new GetFeeTypeProductBrandEmpowerRespVO();
            respVO.setFeeType("0");
            respVO.setRecordMode("0");
            return respVO;
        }
        GetFeeTypeProductBrandEmpowerRespVO respVO = new GetFeeTypeProductBrandEmpowerRespVO();
        //备案状态
        respVO.setRecordMode(brandRespVo.getFiling());
        //todo 目前固定发货人，因为发货人一定有customerId,实际改成根据付款人是谁，获取对应客户id
//        Long customerId = productBrankMapper.getCustomerIdByProductBrandByOrderId(reqVO.getOrderId());
//        respVO.setFeeType(getGetFeeTypeProductBrandEmpowerRespVO(reqVO, productBrankDO, brandRespVo, respVO, customerId));
        // 此业务为比较收发货人的品牌收费模式，取价格低的
        respVO.setFeeType(getGetFeeTypeProductBrandEmpowerRespVO(reqVO, productBrankDO, brandRespVo, respVO));
        return respVO;
    }

    @Nullable
    private String getGetFeeTypeProductBrandEmpowerRespVO(GetFeeTypeProductBrandByOrderEmpowerReqVO reqVO, ProductBrankDO productBrankDO, ProductBrankRespVO brandRespVo, GetFeeTypeProductBrandEmpowerRespVO respVO, Long customerId) {
        if (customerId != null && customerId != 0) {
            //查看品牌与客户授权关系
            ProductBrandEmpowerBaseVO productBrandEmpowerBaseVO = new ProductBrandEmpowerBaseVO();
            productBrandEmpowerBaseVO.setProductBrandId(reqVO.getBrandId());
            productBrandEmpowerBaseVO.setCustomerId(customerId);
            productBrandEmpowerBaseVO.setStatus(CommonStatusEnum.ENABLE.getStatus());
            //查询的授权信息
            List<ProductBrandEmpowerDO> list = getProductBrandEmpowerList(productBrandEmpowerBaseVO);
            //没有授权的客户
            if (list == null || list.size() == 0) {
                //未授权要查看品牌的授权模式，以及当前客户是否有特殊设置
                if (productBrankDO.getUnauthChargingModel().equals("1")) {
                    ProductBrandUnauthEmpowerQueryVO productBrandUnauthEmpowerQueryVO = new ProductBrandUnauthEmpowerQueryVO();
                    productBrandUnauthEmpowerQueryVO.setProductBrandId(reqVO.getBrandId());
                    productBrandUnauthEmpowerQueryVO.setCustomerId(customerId);
                    List<ProductBrandUnauthEmpowerDO> unauthEmpowerList = productBrandUnauthEmpowerService.getProductBrandUnauthEmpowerList(productBrandUnauthEmpowerQueryVO);
                    if (unauthEmpowerList != null && unauthEmpowerList.size() > 0) {
                        //有未授权客户设置
                        return String.valueOf(unauthEmpowerList.get(0).getFeeScale());
                    } else {
                        //未设置以品牌设置为准
                        return brandRespVo.getUnauthDefaultFeeType();
                    }
                } else {
                    //品牌的未授权为统一模式，所有用户以品牌设置为准
                    return brandRespVo.getUnauthDefaultFeeType();
                }
            } else {
                //有授权绑定关系
                ProductBrandEmpowerDO empowerDO = list.get(0);
                if (empowerDO.getAuthType() != null && empowerDO.getAuthType() == 1) {
                    if (empowerDO.getStartTime() != null && empowerDO.getEndTime() != null) {
                        if (DateUtils.afterNow(empowerDO.getStartTime()) || DateUtils.beforeNow(empowerDO.getEndTime())) {
                            return "1";
                        }
                    }
                } else {
                    //使用系统中的授权关系
                    return String.valueOf(empowerDO.getFeeScale());
                }
            }
        }
        return brandRespVo.getFiling();
    }

    @Nullable
    private String getGetFeeTypeProductBrandEmpowerRespVO(GetFeeTypeProductBrandByOrderEmpowerReqVO reqVO, ProductBrankDO productBrankDO, ProductBrankRespVO brandRespVo, GetFeeTypeProductBrandEmpowerRespVO respVO) {
        Long norCustomerId = productBrankMapper.getNorCustomerIdByOrderId(reqVO.getOrderId());
        Long neeCustomerId = productBrankMapper.getNeeCustomerIdByOrderId(reqVO.getOrderId());

        if ((norCustomerId != null && norCustomerId != 0) || (neeCustomerId != null && neeCustomerId != 0)) {
            //查看品牌与客户授权关系
            ProductBrandEmpowerBaseVO norProductBrandEmpowerBaseVO = new ProductBrandEmpowerBaseVO();
            norProductBrandEmpowerBaseVO.setProductBrandId(reqVO.getBrandId());
            norProductBrandEmpowerBaseVO.setCustomerId(Objects.isNull(norCustomerId) ? 0 : norCustomerId);
            norProductBrandEmpowerBaseVO.setStatus(CommonStatusEnum.ENABLE.getStatus());
            //查询的授权信息
            List<ProductBrandEmpowerDO> norList = getProductBrandEmpowerList(norProductBrandEmpowerBaseVO);

            //查看品牌与客户授权关系
            ProductBrandEmpowerBaseVO neeProductBrandEmpowerBaseVO = new ProductBrandEmpowerBaseVO();
            neeProductBrandEmpowerBaseVO.setProductBrandId(reqVO.getBrandId());
            neeProductBrandEmpowerBaseVO.setCustomerId(Objects.isNull(neeCustomerId) ? 0 : neeCustomerId);
            neeProductBrandEmpowerBaseVO.setStatus(CommonStatusEnum.ENABLE.getStatus());
            //查询的授权信息
            List<ProductBrandEmpowerDO> neeList = getProductBrandEmpowerList(neeProductBrandEmpowerBaseVO);
            //没有授权的客户
            if ((norList == null || norList.size() == 0) && (neeList == null || neeList.size() == 0)) {
                //未授权要查看品牌的授权模式，以及当前客户是否有特殊设置
                if (productBrankDO.getUnauthChargingModel().equals("1")) {
                    ProductBrandUnauthEmpowerQueryVO productBrandUnauthEmpowerQueryVO = new ProductBrandUnauthEmpowerQueryVO();
                    productBrandUnauthEmpowerQueryVO.setProductBrandId(reqVO.getBrandId());
                    productBrandUnauthEmpowerQueryVO.setCustomerId(norCustomerId);
                    List<ProductBrandUnauthEmpowerDO> unauthEmpowerList = productBrandUnauthEmpowerService.getProductBrandUnauthEmpowerList(productBrandUnauthEmpowerQueryVO);
                    if (unauthEmpowerList != null && unauthEmpowerList.size() > 0) {
                        //有未授权客户设置
                        return String.valueOf(unauthEmpowerList.get(0).getFeeScale());
                    } else {
                        //未设置以品牌设置为准
                        return brandRespVo.getUnauthDefaultFeeType();
                    }
                } else {
                    //品牌的未授权为统一模式，所有用户以品牌设置为准
                    return brandRespVo.getUnauthDefaultFeeType();
                }
            }

            //有授权绑定关系
            ProductBrandEmpowerDO norEmpowerDO = Objects.nonNull(norList) && CollectionUtil.isNotEmpty(norList) ? norList.get(0) : null;
            ProductBrandEmpowerDO neeEmpowerDO = Objects.nonNull(neeList) && CollectionUtil.isNotEmpty(neeList) ? neeList.get(0) : null;

            String norFeeType = getFeeType(norEmpowerDO);
            String neeFeeType = getFeeType(neeEmpowerDO);
            if (StringUtils.isNotBlank(norFeeType) && StringUtils.isNotBlank(neeFeeType)) {
                // 收发货人都有设置，判断价格低的取值
                ProductLineBrandPriceVO lineVO = productBrankMapper.getLineAndChannelByOrderId(reqVO.getOrderId());
                if (Objects.isNull(lineVO)) {
                    throw exception(ORDER_NOT_EXISTS);
                }
                // 根据商品ID与线路ID获取商品的品牌加价
                ProductLineBrandPriceVO brandPriceVO = productBrankMapper.getProductLineBrandPrice(lineVO.getLineId(), lineVO.getChannelId(), reqVO.getProductId());
                // 获取价格最小的收费模式
                return (norFeeType.equals("0") || neeFeeType.equals("0")) ?
                        "0" : (Objects.nonNull(brandPriceVO) && brandPriceVO.getHave().compareTo(brandPriceVO.getNeutral()) > 0 ?
                        ((norFeeType.equals("2") || neeFeeType.equals("2")) ? "2" : "1") : ((norFeeType.equals("1") || neeFeeType.equals("1")) ? "1" : "2"));
            } else {
                return StringUtils.isNotBlank(norFeeType) ? norFeeType : neeFeeType;
            }
        }
        return brandRespVo.getFiling();
    }

    private static String getFeeType(ProductBrandEmpowerDO empowerDO) {
        String feeType = "";
        if (Objects.nonNull(empowerDO)) {
            //使用系统中的授权关系
            feeType = String.valueOf(empowerDO.getFeeScale());
            if (empowerDO.getAuthType() != null && empowerDO.getAuthType() == 1) {
                if (empowerDO.getStartTime() != null && empowerDO.getEndTime() != null) {
                    if (DateUtils.afterNow(empowerDO.getStartTime()) || DateUtils.beforeNow(empowerDO.getEndTime())) {
                        feeType = "1";
                    }
                }
            }
        }
        return feeType;
    }

    @Override
    public List<ProductBrandEmpowerDO> getProductBrandEmpowerList(Collection<Long> ids) {
        return productBrandEmpowerMapper.selectBatchIds(ids);
    }

    @Override
    public List<ProductBrandEmpowerDO> getProductBrandEmpowerList(ProductBrandEmpowerBaseVO empowerBaseVO) {
        return productBrandEmpowerMapper.selectList(empowerBaseVO);
    }

    @Override
    public PageResult<ProductBrandEmpowerDO> getProductBrandEmpowerPage(ProductBrandEmpowerPageReqVO pageReqVO) {
        return productBrandEmpowerMapper.selectPage(pageReqVO);
    }

    @Override
    public PageResult<ProductBrandEmpowerRespVO> getProductBrandEmpowerCustomerPage(ProductBrandEmpowerPageReqVO pageReqVO) {
        IPage<ProductBrandEmpowerPageReqVO> mpPage = MyBatisUtils.buildPage(pageReqVO);
        pageReqVO.setPageNo((int) ((mpPage.getCurrent() - 1) * mpPage.getSize()));
        pageReqVO.setPageSize((int) (mpPage.getSize()));
        Long total = productBrandEmpowerMapper.countAuthCustomerList(pageReqVO);
        List<ProductBrandEmpowerRespVO> list = productBrandEmpowerMapper.authCustomerList(pageReqVO);
//        List<ProductBrandEmpowerRespVO> respVOList=ProductBrandEmpowerConvert.INSTANCE.convertList(list);
        return new PageResult<>(list, total, mpPage.getSize(), mpPage.getCurrent(), (total + mpPage.getSize() - 1) / mpPage.getSize());
    }

    @Override
    public PageResult<ProductBrandEmpowerRespVO> getProductBrandEmpowerUnAuthCustomerPage(ProductBrandEmpowerPageReqVO pageReqVO) {
        IPage<ProductBrandEmpowerPageReqVO> mpPage = MyBatisUtils.buildPage(pageReqVO);
        pageReqVO.setPageNo((int) ((mpPage.getCurrent() - 1) * mpPage.getSize()));
        pageReqVO.setPageSize((int) (mpPage.getSize()));
        Long total = productBrandEmpowerMapper.countUnAuthCustomerList(pageReqVO);
        List<ProductBrandEmpowerRespVO> list = productBrandEmpowerMapper.unAuthCustomerFeeScaleList(pageReqVO);
//        List<ProductBrandEmpowerRespVO> respVOList=ProductBrandEmpowerConvert.INSTANCE.convertList(list);
        return new PageResult<>(list, total, mpPage.getSize(), mpPage.getCurrent(), (total + mpPage.getSize() - 1) / mpPage.getSize());
    }

    @Override
    public List<ProductBrandEmpowerDO> getProductBrandEmpowerList(ProductBrandEmpowerExportReqVO exportReqVO) {
        return productBrandEmpowerMapper.selectList(exportReqVO);
    }

}
